@@ -1,6 +1,6 @@
 /*************************************************************************
 **
-**  Copyright 1982-2008 Pervasive Software Inc. All Rights Reserved
+**  Copyright 2014 Actian Corporation All Rights Reserved
 **
 *************************************************************************/
 /***************************************************************************
@@ -54,7 +54,7 @@
    IMPORTANT: You should modify the following to specify the
               complete path to 'sample.btr' for your environment.
 ********************************************************************/
-#if defined(BTI_LINUX) || defined(BTI_LINUX_64)
+#if defined(BTI_LINUX) || defined(BTI_LINUX_64) || defined(BTI_MACOSX) || defined(BTI_MACOSX_64)
 #define FILE1_NAME "/usr/local/psql/data/samples/sample.btr"
 #define FILE2_NAME "/usr/local/psql/data/samples/sample2.btr"
 #else
@@ -62,8 +62,8 @@
 #define FILE1_NAME "sys:\\pvsw\\samples\\sample.btr"
 #define FILE2_NAME "sys:\\pvsw\\samples\\sample2.btr"
 #else
-#define FILE1_NAME "C:\\Documents and Settings\\All Users\\Application Data\\Pervasive Software\\PSQL\\samples\\sample.btr"
-#define FILE2_NAME "C:\\Documents and Settings\\All Users\\Application Data\\Pervasive Software\\PSQL\\samples\\sample2.btr"
+#define FILE1_NAME "c:\\ProgramData\\Actian\\PSQL\\samples\\sample.btr" 
+#define FILE2_NAME "c:\\ProgramData\\Actian\\PSQL\\samples\\sample2.btr"
 #endif
 #endif
 
@@ -80,7 +80,7 @@
 #if defined(__BORLANDC__)
   #pragma option -a-
 #else
-  #if defined(_MSC_VER) || defined(__WATCOMC__) || defined(BTI_LINUX) || defined(BTI_LINUX_64)
+  #if defined(_MSC_VER) || defined(__WATCOMC__) || defined(BTI_LINUX) || defined(BTI_LINUX_64) || defined(BTI_MACOSX) || defined(BTI_MACOSX_64)
     #pragma pack(1)
   #endif
 #endif
@@ -217,7 +217,7 @@ typedef union
 #if defined(__BORLANDC__)
   #pragma option -a.
 #else
-  #if defined(_MSC_VER) || defined(__WATCOMC__) || defined(BTI_LINUX) || defined(BTI_LINUX_64)
+  #if defined(_MSC_VER) || defined(__WATCOMC__) || defined(BTI_LINUX) || defined(BTI_LINUX_64) || defined(BTI_MACOSX) || defined(BTI_MACOSX_64)
     #pragma pack()
   #endif
 #endif
@@ -350,7 +350,11 @@ int main(void)
     {
       printf("\n");
       printf("The retrieved record is:\n");
+#ifdef BTI_MACOSX_64
+      printf("ID:      %d\n", personRecord.ID);
+#else
       printf("ID:      %ld\n", personRecord.ID);
+#endif
       printf("Name:    %s %s\n", personRecord.FirstName,
                                  personRecord.LastName);
       printf("Street:  %s\n", personRecord.Street);
@@ -559,8 +563,15 @@ int main(void)
   if (btrieveLoaded)
   {
     dataLen = 0;
-    status = BTRVID(B_STOP, posBlock1, dataBuf, &dataLen, keyBuf1, keyNum,
-             (BTI_BUFFER_PTR)&clientID);
+    status = BTRVID(
+		          B_STOP, 
+					 posBlock1, 
+					 dataBuf, 
+					 &dataLen, 
+					 keyBuf1, 
+					 keyNum,
+                (BTI_BUFFER_PTR)&clientID);
+
     printf("Btrieve STOP status = %d\n", status);
     if (status != B_NO_ERROR)
     {
