@@ -1,7 +1,7 @@
 #ifndef _BTRCONST_H_INCLUDED
 /*************************************************************************
 **
-**  Copyright 1982-2008 Pervasive Software Inc. All Rights Reserved
+**  Copyright 2014 Actian Corporation All Rights Reserved
 **
 *************************************************************************/
 /***************************************************************************
@@ -22,7 +22,7 @@
 
 #define BLOB_HEADER_LEN   0x0014     /* record chunk offset */
 
-#if defined (BTI_DOS) || defined (BTI_WIN) || defined (BTI_WIN_32) || defined (BTI_DOS_32R) || defined (BTI_DOS_32P) || defined (BTI_DOS_32B) || defined (BTI_SOL) || defined (BTI_HPUX) || defined (BTI_AIX) || defined (BTI_IRIX) || defined (BTI_DEC_UNIX) || defined (BTI_LINUX) || defined(BTI_LINUX_64) || defined (BTI_WIN_64)
+#if defined (BTI_DOS) || defined (BTI_WIN) || defined (BTI_WIN_32) || defined (BTI_DOS_32R) || defined (BTI_DOS_32P) || defined (BTI_DOS_32B) || defined (BTI_SOL) || defined (BTI_HPUX) || defined (BTI_AIX) || defined (BTI_IRIX) || defined (BTI_DEC_UNIX) || defined (BTI_LINUX) || defined(BTI_LINUX_64) || defined (BTI_WIN_64) || defined(BTI_MACOSX) || defined(BTI_MACOSX_64)
 #define MAX_DATABUF_SIZE  57000L
 #define MAX_STATBUF_SIZE  57000L     /* B_STAT maximum data buffer size */
 #endif
